=========
Crackhash
=========


.. image:: https://img.shields.io/pypi/v/crackhash.svg
        :target: https://pypi.python.org/pypi/crackhash

.. image:: https://readthedocs.org/projects/crackhash/badge/?version=latest
        :target: https://crackhash.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/crackhash.svg
        :target: https://pypi.python.org/pypi/crackhash

.. image:: https://travis-ci.com/5h4d0wb0y/crackhash.svg?branch=master
        :target: https://travis-ci.com/5h4d0wb0y/crackhash

.. image:: https://codecov.io/github/5h4d0wb0y/crackhash/coverage.svg?branch=master
        :target: https://codecov.io/github/5h4d0wb0y/crackhash?branch=master



Crackhash is a tool that try to crack different types of hashes using free online services.


* Free software: GNU General Public License v3
* Documentation: https://crackhash.readthedocs.io.


Features
--------

* Browser supports proxy configuration
* Automatic hash type identification
* Can crack hashes from a file 
* Algorith supported
        * MD5 - RFC 1321
        * SHA1 - RFC 3174 (FIPS 180-3)
        * SHA256 - FIPS 180-3
        * SHA384 - FIPS 180-3
        * SHA512 - FIPS 180-3
        * LM - Microsoft Windows hash NTLM - Microsoft Windows hash
        * NTLM Support
        * MYSQL - MySQL 3, 4, 5 hash
        * CISCO - Cisco IOS type 7 encrypted passwords
        * JUNIPER - Juniper Networks $9$ encrypted passwords
        * RMD128 Support
        * RMD160 - RFC 2857
        * RMD256 Support
        * RMD320 Support
        * GOST - RFC 583
        * WHIRLPOOL - ISO/IEC 10118-3:2004
        * LDAP_MD5 - MD5 Base64 encoded
        * LDAP_SHA1 - SHA1 Base64 encoded


Available Services
------------------

It checks the hash in the following services on-line:

* md5.my-addr.com
* nitrxgen.net
* md5decrypt.net
* hashcrack.com
* hashtoolkit.com
* md5hashing.net
* hashkiller.co.uk
* password-decrypt.com
* m00nie.com
* firewallruletest.com
* ifm.net.nz
* ibeast.com
* cmd5.org
* rainbowtables.it64.com


Credits
-------

This package was developed by @5h4d0wb0y_.

.. _@5h4d0wb0y: https://twitter.com/5h4d0wb0y


Stargazers over time
--------------------

.. image:: https://starchart.cc/5h4d0wb0y/crackhash.svg
        :target: https://starchart.cc/5h4d0wb0y/crackhash
        :alt: Stargazers over time